/**
  *  \file client/widgets/funcinfo.cc
  *  \brief Hull Function Information Widget
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/funcinfo.h"
#include "cpluslib/format.h"
#include "util/nls.h"
#include "game/struct.h"
#include "ui/uiglobal.h"
#include "ui/skin.h"
#include "ui/util.h"

WHullFunctionInfo::WHullFunctionInfo()
    : UIRichDocument(font_sizes[FONT_NORMAL].scaledBy(30, 11), 0)
{ }

WHullFunctionInfo::~WHullFunctionInfo()
{ }

void
WHullFunctionInfo::setFunction(const GHullFunction* hf)
{
    RichDocument& doc = getDocument();
    doc.clear();
    if (hf != 0) {
        /* Function title */
        const GBasicHullFunction* ptr = GHullFunctionData::instance.getBasicFunctionById(hf->getBasicFunctionId());
        if (ptr) {
            doc.add(RichText(ptr->getDescription()).withAttribute(RichTextStyleAttribute::Bold));
        } else {
            doc.add(RichText(format(_("Hull Function #%d"), hf->getBasicFunctionId())).withAttribute(RichTextStyleAttribute::Bold));
        }
        doc.addParagraph();

        /* Availability information */
        string_t tmp = formatPlayerSet(hf->getPlayers());
        if (tmp.size()) {
            doc.add(string_t(format(_("Available to %s"), tmp)));
            doc.addNewline();
        }
        tmp = formatExpLevelSet(hf->getLevels());
        if (tmp.size()) {
            doc.add(string_t(format(_("Available at %s"), tmp)));
            doc.addNewline();
        }

        if (hf->getKind() == GHullFunction::AssignedToRace) {
            if (hf->getPlayers().contains(GPlayerSet::allUpTo(NUM_PLAYERS) - 0)) {
                doc.add(_("Universal ability"));
            } else {
                doc.add(_("Racial ability"));
            }
        } else if (hf->getKind() == GHullFunction::AssignedToShip) {
            doc.add(_("Assigned to ship"));
        } else {
            doc.add(_("Assigned to ship class"));
        }
        doc.addParagraph();

        /* Description */
        if (ptr) {
            doc.add(ptr->getExplanation());
        }
    }
    doc.finish();
    handleDocumentUpdate();
}
