/**
  *  \file tests/testres.cc
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include <iostream>
#include <string.h>
#include <SDL.h>
#include "resmgr/res-cc1.h"
#include "io/streams.h"
#include "gfx/pixmap.h"
#include "util/except.h"
#include "util/modinit.h"

static int lorange = 0, hirange = 0x7fff;

static void
testFile(const char* name)
{
    Ptr<Stream> worker = Stream::openFile(name, Stream::C_READ);
    Ptr<ResourceStream> res = new ResourceStream(worker);

    for (uint16 i = lorange; i <= hirange; ++i) {
        if (res->seekId(i)) {
            std::cout << i << ":" << std::flush;
            try {
                Ptr<GfxPixmap> p = loadImage(res);
                if (p) {
                    std::cout << " " << p->getWidth() << " x " << p->getHeight() << "\n";
                } else {
                    std::cout << " not a pixmap\n";
                }
            }
            catch (std::exception& e) {
                std::cout << " exception " << e.what() << "\n";
            }
        }
    }
}


int main(int argc, char** argv)
{
    performInitialisation(OnStartup, mod_base_gui);
    argv = Platform::convertArgumentsToUtf8(argv);

    SDL_Init(SDL_INIT_VIDEO | SDL_INIT_NOPARACHUTE);
    
    for (int i = 1; argv[i] != 0; ++i) {
        /* Special Arguments */
        if (sscanf(argv[i], "lo=%d", &lorange) == 1)
            continue;
        if (sscanf(argv[i], "hi=%d", &hirange) == 1)
            continue;

        try {
            testFile(argv[i]);
        }
        catch (FileFormatException& e) {
            std::cout << argv[i] << ": FileFormatException: " << e.what() << "\n";
        }
        catch (...) {
            std::cout << argv[i] << ": exception\n";
        }
    }

    SDL_Quit();
}
