/**
  *  \file ui/dialogs/filedlg.h
  *  \brief File Chooser Dialog
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_UI_DIALOGS_FILEDLG_H
#define PCC_V2_UI_DIALOGS_FILEDLG_H

#include "ui/window.h"
#include "io/dirs.h"

class UIFileChooser;
class UIInputLine;
class UIDirectoryCrumbTrail;

/** File chooser dialog. Displays a file list (UIFileChooser), an input
    line and a crumb trail, to select a file.

    To use this dialog, call runModal with a UIFileChooserDialog
    object. If it returns nonzero, the dialog was confirmed and you
    can obtain the result file using getResultFile(). */
class UIFileChooserDialog : public UIWindow {
    ObjectHolder h;
    UIFileChooser* file_chooser;
    UIInputLine* input_line;
    UIDirectoryCrumbTrail* crumb_trail;

    void init(Ptr<Directory> initial_directory, string_t wildcard);
    void onEnter();
    void onFinish();
    void onCrumbClick(int n);
    void onDirChange();
 public:
    UIFileChooserDialog(string_t title, Ptr<Directory> initial_directory, string_t wildcard);
    ~UIFileChooserDialog();

    bool handleEvent(const UIEvent& event, bool second_pass);

    const string_t& getResultFile() const;
};

#endif
